#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gdkpixbuf
version:                2.0.32
visibility:             public
id:                     gi-gdkpixbuf-2.0.32-9U7Tlh8IAKLEcxl8Y4sizo
key:                    gi-gdkpixbuf-2.0.32-9U7Tlh8IAKLEcxl8Y4sizo
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               GdkPixbuf bindings
description:            Bindings for GdkPixbuf, autogenerated by haskell-gi.
category:               Bindings
abi:                    c10575fd164fda721c1c7def8695993e
exposed:                True
exposed-modules:
    GI.GdkPixbuf GI.GdkPixbuf.Callbacks GI.GdkPixbuf.Config
    GI.GdkPixbuf.Constants GI.GdkPixbuf.Enums GI.GdkPixbuf.Flags
    GI.GdkPixbuf.Objects GI.GdkPixbuf.Objects.Pixbuf
    GI.GdkPixbuf.Objects.PixbufAnimation
    GI.GdkPixbuf.Objects.PixbufAnimationIter
    GI.GdkPixbuf.Objects.PixbufLoader
    GI.GdkPixbuf.Objects.PixbufNonAnim
    GI.GdkPixbuf.Objects.PixbufSimpleAnim
    GI.GdkPixbuf.Objects.PixbufSimpleAnimIter GI.GdkPixbuf.Structs
    GI.GdkPixbuf.Structs.PixbufFormat GI.GdkPixbuf.Structs.PixbufModule
    GI.GdkPixbuf.Structs.PixbufModulePattern

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gdkpixbuf-2.0.32
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-gdkpixbuf-2.0.32 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-gdkpixbuf-2.0.32 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gdkpixbuf
hs-libraries:           HSgi-gdkpixbuf-2.0.32-9U7Tlh8IAKLEcxl8Y4sizo
extra-libraries:        gdk_pixbuf-2.0 gobject-2.0 glib-2.0
extra-libraries-static:
    gdk_pixbuf-2.0 m glycin-2 fontconfig m freetype dl bz2 png16 m m
    brotlidec brotlicommon expat m seccomp lcms2 m pthread gio-2.0
    gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m pcre2-8 pthread z
    mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2 /usr/include
    /usr/include/freetype2 /usr/include/libpng16 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/libmount /usr/include/blkid
    /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-gio-2.0.38-6ha6pZpIQuC8fwOimSYVCM
    gi-glib-2.0.30-1h7nFfSnHMSCaekTNIFRAR
    gi-gmodule-2.0.6-BlNBn9C7uLxKji9SJvcOKs
    gi-gobject-2.0.31-KylFVDZ031A4KuOvSUDXa8
    haskell-gi-0.26.17-KTKuaDiIzQnJmzsAng7Qts
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-gi-gdkpixbuf/html/gi-gdkpixbuf.haddock

haddock-html:           /usr/share/doc/haskell-gi-gdkpixbuf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

